@@ -4,12 +4,12 @@ if (require("testthat") && require("modelbased") && require("rstanarm") && requi
       data <- mtcars
       data$gear <- as.factor(data$gear)
 
-      model <- rstanarm::stan_glm(mpg ~ wt * gear, data = data, refresh = 0, iter = 200, chains = 2)
+      model <- suppressWarnings(rstanarm::stan_glm(mpg ~ wt * gear, data = data, refresh = 0, iter = 200, chains = 2))
       estim <- estimate_means(model)
       testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
 
       data$cyl <- as.factor(data$cyl)
-      model <- rstanarm::stan_glm(vs ~ cyl, data = data, refresh = 0, iter = 200, chains = 2)
+      model <- suppressWarnings(rstanarm::stan_glm(vs ~ cyl, data = data, refresh = 0, iter = 200, chains = 2))
       estim <- estimate_means(model)
       testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
 
@@ -18,11 +18,11 @@ if (require("testthat") && require("modelbased") && require("rstanarm") && requi
       data <- iris
       data$Petal.Length_factor <- ifelse(data$Petal.Length < 4.2, "A", "B")
 
-      model <- rstanarm::stan_glm(Sepal.Width ~ Species * Petal.Length_factor, data = data, refresh = 0, iter = 200, chains = 2)
+      model <- suppressWarnings(rstanarm::stan_glm(Sepal.Width ~ Species * Petal.Length_factor, data = data, refresh = 0, iter = 200, chains = 2))
       estim <- estimate_means(model)
       testthat::expect_equal(c(nrow(estim), ncol(estim)), c(6, 5))
 
-      model <- rstanarm::stan_glm(Petal.Length ~ Sepal.Width + Species, data = iris, refresh = 0, iter = 200, chains = 2)
+      model <- suppressWarnings(rstanarm::stan_glm(Petal.Length ~ Sepal.Width + Species, data = iris, refresh = 0, iter = 200, chains = 2))
       estim <- estimate_means(model)
       testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
 
